Chuck class final

Constructors

Chuck({GlobalKey<NavigatorState>? navigatorKey, bool showNotification = true, bool showInspectorOnShake = false, String notificationIcon = '@mipmap/ic_launcher', int maxCallsCount = 1000})
Creates Chuck instance.

Properties

dioInterceptor ChuckDioInterceptor
Get Dio interceptor which should be applied to Dio instance.
no setter
hashCode int
The hash code for this object.
no setterinherited
maxCallsCount int
Max number of calls that are stored in memory. When count is reached, FIFO method queue will be used to remove elements.
final
Get currently used navigation key
no setter
notificationIcon String
Icon url for notification
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showInspectorOnShake bool
Should inspector be opened on device shake (works only with physical with sensors)
final
showNotification bool
Should user be notified with notification if there's new request catched by Chuck
final

Methods

addHttpCall(ChuckHttpCall chuckHttpCall) → void
Handle generic http call. Can be used to any http client.
dispose() → void
Dispose of resources used by Chuck. Call this method when Chuck is no longer needed to prevent memory leaks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onHttpClientRequest(HttpClientRequest request, {Object? body}) → void
Handle request from HttpClient
onHttpClientResponse(HttpClientResponse response, HttpClientRequest request, {Object? body}) Future<void>
Handle response from HttpClient
onHttpResponse(Response response, {Object? body}) → void
Handle both request and response from http package
setNavigatorKey(GlobalKey<NavigatorState> navigatorKey) → void
Set custom navigation key. This will help if there's route library.
showInspector() → void
Opens Http calls inspector. This will navigate user to the new fullscreen page where all listened http calls can be viewed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited